@@ -1,7 +1,7 @@
-import $ from 'jquery';
-import storage from './storage';
+const $ = require('jquery');
+const storage = require('./storage');
 
-module.exports = function (input, output) {
+export default function (input, output) {
 
   const $left = input.$el.parent();
 
