@@ -5,7 +5,7 @@ let x_json = require('./x_json_highlight_rules');
 var oop = ace.require("ace/lib/oop");
 var JsonHighlightRules = ace.require("ace/mode/json_highlight_rules").JsonHighlightRules;
 
-var OutputJsonHighlightRules = function () {
+export function OutputJsonHighlightRules() {
 
   this.$rules = {};
 
@@ -26,8 +26,6 @@ var OutputJsonHighlightRules = function () {
     this.normalizeRules();
   }
 
-};
+}
 
 oop.inherits(OutputJsonHighlightRules, JsonHighlightRules);
-
-module.exports.OutputJsonHighlightRules = OutputJsonHighlightRules;
