@@ -1,22 +1,21 @@
-import { VisVisTypeProvider } from 'ui/vis/vis_type';
-import { VislibVisTypeVislibVisTypeProvider } from 'ui/vislib_vis_type/vislib_vis_type';
-import { VisSchemasProvider } from 'ui/vis/schemas';
+import { VisFactoryProvider } from 'ui/vis/vis_factory';
+import { VisSchemasProvider } from 'ui/vis/editors/default/schemas';
+import { CATEGORY } from 'ui/vis/vis_category';
 import gaugeTemplate from 'plugins/kbn_vislib_vis_types/editors/gauge.html';
 import { vislibColorMaps } from 'ui/vislib/components/color/colormaps';
 import image from './images/icon-number.svg';
 
 export default function MetricVisType(Private) {
-  const VisType = Private(VisVisTypeProvider);
-  const VislibVisType = Private(VislibVisTypeVislibVisTypeProvider);
+  const VisFactory = Private(VisFactoryProvider);
   const Schemas = Private(VisSchemasProvider);
 
-  return new VislibVisType({
+  return VisFactory.createVislibVisualization({
     name: 'metric',
     title: 'Metric',
     image,
     description: 'Display a calculation as a single number',
-    category: VisType.CATEGORY.DATA,
-    params: {
+    category: CATEGORY.DATA,
+    visConfig: {
       defaults: {
         addTooltip: true,
         addLegend: false,
@@ -55,32 +54,35 @@ export default function MetricVisType(Private) {
           }
         }
       },
-      gaugeTypes: ['Arc', 'Circle', 'Metric'],
-      gaugeColorMode: ['None', 'Labels', 'Background'],
-      scales: ['linear', 'log', 'square root'],
-      colorSchemas: Object.keys(vislibColorMaps),
-      editor: gaugeTemplate
     },
-    implementsRenderComplete: true,
-    schemas: new Schemas([
-      {
-        group: 'metrics',
-        name: 'metric',
-        title: 'Metric',
-        min: 1,
-        aggFilter: ['!derivative', '!geo_centroid'],
-        defaults: [
-          { schema: 'metric', type: 'count' }
-        ]
+    editorConfig: {
+      collections: {
+        gaugeTypes: ['Arc', 'Circle', 'Metric'],
+        gaugeColorMode: ['None', 'Labels', 'Background'],
+        scales: ['linear', 'log', 'square root'],
+        colorSchemas: Object.keys(vislibColorMaps),
       },
-      {
-        group: 'buckets',
-        name: 'group',
-        title: 'Split Group',
-        min: 0,
-        max: 1,
-        aggFilter: '!geohash_grid'
-      }
-    ])
+      optionsTemplate: gaugeTemplate,
+      schemas: new Schemas([
+        {
+          group: 'metrics',
+          name: 'metric',
+          title: 'Metric',
+          min: 1,
+          aggFilter: ['!derivative', '!geo_centroid','!geo_bounds'],
+          defaults: [
+            { schema: 'metric', type: 'count' }
+          ]
+        },
+        {
+          group: 'buckets',
+          name: 'group',
+          title: 'Split Group',
+          min: 0,
+          max: 1,
+          aggFilter: ['!geohash_grid', '!filter']
+        }
+      ])
+    }
   });
 }
