@@ -1,5 +1,4 @@
 import _ from 'lodash';
-import { getDefaultQuery } from 'ui/parse_query';
 
 /**
  * @typedef {Object} QueryFilter
@@ -34,9 +33,13 @@ export class FilterUtils {
    * @returns {QueryFilter}
    */
   static getQueryFilterForDashboard(dashboard) {
+    if (dashboard.searchSource.getOwn('query')) {
+      return dashboard.searchSource.getOwn('query');
+    }
+
     const dashboardFilters = this.getDashboardFilters(dashboard);
     const dashboardQueryFilter = _.find(dashboardFilters, this.isQueryFilter);
-    return dashboardQueryFilter ? dashboardQueryFilter.query : getDefaultQuery();
+    return dashboardQueryFilter ? dashboardQueryFilter.query : '';
   }
 
   /**
