@@ -1,19 +1,15 @@
 export function sendCreateIndexPatternRequest(indexPatterns, {
   id,
+  name,
   timeFieldName,
-  intervalName,
-  notExpandable,
 }) {
   // get an empty indexPattern to start
   return indexPatterns.get()
     .then(indexPattern => {
-      // set both the id and title to the same value
-      indexPattern.id = indexPattern.title = id;
-
       Object.assign(indexPattern, {
+        id,
+        title: name,
         timeFieldName,
-        intervalName,
-        notExpandable,
       });
 
       // fetch the fields
