@@ -4,7 +4,7 @@ import './indexed_fields_table';
 import './scripted_fields_table';
 import './scripted_field_editor';
 import './source_filters_table';
-import UrlProvider from 'ui/url';
+import { KbnUrlProvider } from 'ui/url';
 import { IndicesEditSectionsProvider } from './edit_sections';
 import uiRoutes from 'ui/routes';
 import { uiModules } from 'ui/modules';
@@ -44,7 +44,7 @@ uiModules.get('apps/management')
   const notify = new Notifier();
   const $state = $scope.state = new AppState();
 
-  $scope.kbnUrl = Private(UrlProvider);
+  $scope.kbnUrl = Private(KbnUrlProvider);
   $scope.indexPattern = $route.current.locals.indexPattern;
   docTitle.change($scope.indexPattern.title);
 
