@@ -1,7 +1,7 @@
 import 'plugins/markdown_vis/markdown_vis.less';
 import 'plugins/markdown_vis/markdown_vis_controller';
-import { VisVisTypeProvider } from 'ui/vis/vis_type';
-import { TemplateVisTypeProvider } from 'ui/template_vis_type/template_vis_type';
+import { VisFactoryProvider } from 'ui/vis/vis_factory';
+import { CATEGORY } from 'ui/vis/vis_category';
 import markdownVisTemplate from 'plugins/markdown_vis/markdown_vis.html';
 import markdownVisParamsTemplate from 'plugins/markdown_vis/markdown_vis_params.html';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
@@ -14,22 +14,31 @@ import image from './images/icon-markdown.svg';
 VisTypesRegistryProvider.register(MarkdownVisProvider);
 
 function MarkdownVisProvider(Private) {
-  const VisType = Private(VisVisTypeProvider);
-  const TemplateVisType = Private(TemplateVisTypeProvider);
+  const VisFactory = Private(VisFactoryProvider);
 
   // return the visType object, which kibana will use to display and configure new
   // Vis object of this type.
-  return new TemplateVisType({
+  return VisFactory.createAngularVisualization({
     name: 'markdown',
     title: 'Markdown',
+    isAccessible: true,
     image,
     description: 'Create a document using markdown syntax',
-    category: VisType.CATEGORY.OTHER,
-    template: markdownVisTemplate,
-    params: {
-      editor: markdownVisParamsTemplate
+    category: CATEGORY.OTHER,
+    visConfig: {
+      template: markdownVisTemplate,
+      defaults: {
+        fontSize: 12
+      }
     },
-    requiresSearch: false,
+    editorConfig: {
+      optionsTemplate: markdownVisParamsTemplate
+    },
+    options: {
+      showTimePicker: false,
+    },
+    requestHandler: 'none',
+    responseHandler: 'none',
     implementsRenderComplete: true,
   });
 }
