@@ -1,7 +1,7 @@
 import { uiModules } from 'ui/modules';
 import template from './filter_params_range_editor.html';
-import { documentationLinks } from 'ui/documentation_links/documentation_links';
 import './filter_params_input_type';
+import '../../directives/documentation_href';
 import '../../directives/focus_on';
 
 const module = uiModules.get('kibana');
@@ -12,9 +12,6 @@ module.directive('filterParamsRangeEditor', function () {
     scope: {
       field: '=',
       params: '='
-    },
-    link: function (scope) {
-      scope.dateDocLinks = documentationLinks.date;
     }
   };
 });
