@@ -24,7 +24,7 @@ export function lodashObjectMixin(_) {
       (function flattenObj(obj) {
         _.keys(obj).forEach(function (key) {
           stack.push(key);
-          if (!flattenArrays && _.isArray(obj[key])) flatObj[stack.join(dot)] = obj[key];
+          if (!flattenArrays && Array.isArray(obj[key])) flatObj[stack.join(dot)] = obj[key];
           else if (_.isObject(obj[key])) flattenObj(obj[key]);
           else flatObj[stack.join(dot)] = obj[key];
           stack.pop();
